fp16color

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2024 License: MIT Imports: 2 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

var NRGBAhModel color.Model = color.ModelFunc(nrgbahModel)
var RGBAhModel color.Model = color.ModelFunc(rgbahModel)

Functions

This section is empty.

Types

type NRGBAh

type NRGBAh struct {
	R, G, B, A float16.Float16
}

NRGBAh represents a non-alpha-premultiplied 64-bit color, having 16 bits float for each of red, green, blue and alpha.

func NewNRGBAh

func NewNRGBAh(r, g, b, a float64) NRGBAh

func (NRGBAh) RGBA

func (c NRGBAh) RGBA() (r, g, b, a uint32)

type RGBAh

type RGBAh struct {
	R, G, B, A float16.Float16
}

RGBAh represents an alpha-premultiplied 64-bit color, having 16 bits float for each of red, green, blue and alpha.

func NewRGBAh

func NewRGBAh(r, g, b, a float64) RGBAh

func (RGBAh) RGBA

func (c RGBAh) RGBA() (r, g, b, a uint32)

Jump to