Documentation
¶
Overview ¶
Package pnm support Portable Any Map image format.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Encoder ¶
type Encoder struct {
// Plain specifies whether to encode in plain(ASCII) format.
Plain bool
// Type specifies the image type.
Type Type
// Max specifies the maximum value of the image color.
// If Max is 0, the maximum value is determined by the image type.
// If Type is TypePBM, Max is ignored.
Max uint16
}
Encoder is a Portable Any Map image encoder.
Click to show internal directories.
Click to hide internal directories.